==> haskell-crypto-pubkey-types-0.4.3-99-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey-types
version: 0.4.3
id: crypto-pubkey-types-0.4.3-HTrfCaY4HEwKW8Mc7HYdI9
key: crypto-pubkey-types-0.4.3-HTrfCaY4HEwKW8Mc7HYdI9
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis: Generic cryptography Public keys algorithm types
description:
    Generic cryptography public keys algorithm types
category: Cryptography
abi: cc318eed7a6f4865cbde95b9d23a3315
exposed: True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA
import-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-pubkey-types-0.4.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/crypto-pubkey-types-0.4.3
hs-libraries: HScrypto-pubkey-types-0.4.3-HTrfCaY4HEwKW8Mc7HYdI9
depends:
    asn1-encoding-0.9.5-4d2qu1C5140EVy8vWh2yu
    asn1-types-0.3.3-DioBfHlr1F19GPBRFraLWv base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-types-0.4.3-100-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey-types
version: 0.4.3
id: crypto-pubkey-types-0.4.3-9aRaaM1sL6SBo9aXFfpDaA
key: crypto-pubkey-types-0.4.3-9aRaaM1sL6SBo9aXFfpDaA
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis: Generic cryptography Public keys algorithm types
description:
    Generic cryptography public keys algorithm types
category: Cryptography
abi: c6a3ef1c778a2e867fd95ba14103c7bb
exposed: True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA
import-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-pubkey-types-0.4.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/crypto-pubkey-types-0.4.3
hs-libraries: HScrypto-pubkey-types-0.4.3-9aRaaM1sL6SBo9aXFfpDaA
depends:
    asn1-encoding-0.9.5-5KKZW1D8M3iFo1KmhlQDOR
    asn1-types-0.3.3-9kOIcKUQpBeIUvQhC8COjO base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
